@@ -25,9 +25,12 @@ pub mod sha;
 
 use core::{mem, panic::PanicInfo, ptr};
 
-use gpio::{FaultDescriptor, LogDescriptor, GPIO_DESC_FAULT, GPIO_DESC_LOG, GPIO_FAULT, GPIO_LOG};
 use risc0_zkvm_core::{set_logger, Log};
 
+use crate::gpio::{
+    FaultDescriptor, LogDescriptor, GPIO_DESC_FAULT, GPIO_DESC_LOG, GPIO_FAULT, GPIO_LOG,
+};
+
 const REGION_SIZE_256KB: usize = 256 * 1024;
 // const REGION_SIZE_512KB: usize = 0x0008_0000;
 const REGION_SIZE_1MB: usize = 1024 * 1024;
@@ -127,8 +130,9 @@ pub(crate) const fn align_up(addr: usize, align: usize) -> usize {
     (addr + align - 1) & !(align - 1)
 }
 
-#[cfg(feature = "cargo")]
-core::arch::global_asm!(r#"
+#[cfg(not(feature = "bazel"))]
+core::arch::global_asm!(
+    r#"
 .section .text._start;
 .globl _start;
 _start:
@@ -154,4 +158,5 @@ _start:
 .globl _fault;
 _fault:
     sw x0, 1(x0)
-"#);
+"#
+);
